summaryrefslogtreecommitdiffstats
path: root/api/direct_bt/SMPHandler.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'api/direct_bt/SMPHandler.hpp')
-rw-r--r--api/direct_bt/SMPHandler.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/api/direct_bt/SMPHandler.hpp b/api/direct_bt/SMPHandler.hpp
index c75a12a2..6f16eaae 100644
--- a/api/direct_bt/SMPHandler.hpp
+++ b/api/direct_bt/SMPHandler.hpp
@@ -216,12 +216,12 @@ namespace direct_bt {
std::string getStateString() const noexcept { return L2CAPComm::getStateString(is_connected, has_ioerror); }
/**
* If sec_level > BT_SECURITY_LOW, establish security level per L2CAP connection.
*
- * @param sec_level BT_SECURITY_LOW, BT_SECURITY_MEDIUM, BT_SECURITY_HIGH or BT_SECURITY_FIPS. sec_level <= BT_SECURITY_LOW leads to not set security level.
- * @return true if a security level > BT_SECURITY_LOW has been set successfully, false if no security level has been set or if it failed.
+ * @param sec_level sec_level <= BTSecurityLevel::NONE will not set security level and returns false.
+ * @return true if a security level > BTSecurityLevel::NONE has been set successfully, false if no security level has been set or if it failed.
*/
- bool establishSecurity(const uint8_t sec_level);
+ bool establishSecurity(const BTSecurityLevel sec_level);
/**
* Disconnect this GATTHandler and optionally the associated device
@@ -216,12 +216,12 @@ namespace direct_bt {
std::string getStateString() const noexcept { return L2CAPComm::getStateString(is_connected, has_ioerror); }
/**
- * If sec_level > BT_SECURITY_LOW, establish security level per L2CAP connection.
+ * If sec_level > BTSecurityLevel::NONE, establish security level per L2CAP connection.
*